"""Calculates Pointing Set Grids."""

import numpy as np

from imap_processing.ultra.utils.ultra_l1_utils import create_dataset


def calculate_pset(pset_dataset, name):
    """
    Create dictionary with defined datatype for Pointing Set Grid Data.

    Parameters
    ----------
    pset_dataset: xarray.Dataset
        Dataset containing histogram data.
    name: str
        Name of the dataset.

    Returns
    -------
    dataset : xarray.Dataset
        Dataset containing the data.
    """
    pset_dict = {}

    # Placeholder for calculations
    epoch = pset_dataset.coords["epoch"].values

    pset_dict["epoch"] = epoch
    pset_dict["esa_step"] = np.zeros(len(epoch), dtype=np.uint8)

    dataset = create_dataset(pset_dict, name, "l1c")

    return dataset
